multidim.SimplicialComplex
==========================

.. currentmodule:: multidim

.. autoclass:: SimplicialComplex

   

      .. autosummary::
         :toctree:
      
         SimplicialComplex.cells
         SimplicialComplex.check
         SimplicialComplex.from_distances
         SimplicialComplex.make_pers0
         SimplicialComplex.make_pers1_rca1
         SimplicialComplex.reset



   

